@@ -1,4 +1,19 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ * Copyright (C) 2010 - Jesse van den Kieboom
+ *
+ * gedit-collaboration is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * gedit-collaboration is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with gedit-collaboration. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <gedit/gedit-window-activatable.h>
 
@@ -963,13 +978,9 @@ show_password_dialog (GeditCollaborationWindowHelper *helper,
 	gchar *name;
 	gchar *username;
 	gchar *remotename;
-	gchar *datadir;
 	PasswordInfo *info;
 
-	datadir = peas_extension_base_get_data_dir (PEAS_EXTENSION_BASE (helper));
-	builder = gedit_collaboration_create_builder (datadir,
-	                                              "gedit-collaboration-password-dialog.ui");
-	g_free (datadir);
+	builder = gedit_collaboration_create_builder ("gedit-collaboration-password-dialog.ui");
 
 	if (!builder)
 	{
@@ -1555,11 +1566,8 @@ build_ui (GeditCollaborationWindowHelper *helper)
 	GtkWidget *image;
 	GtkBuilder *builder;
 	GtkWidget *paned;
-	gchar *datadir;
 
-	datadir = peas_extension_base_get_data_dir (PEAS_EXTENSION_BASE (helper));
-	builder = gedit_collaboration_create_builder (datadir, XML_UI_FILE);
-	g_free (datadir);
+	builder = gedit_collaboration_create_builder (XML_UI_FILE);
 
 	if (!builder)
 	{
@@ -1592,7 +1600,7 @@ build_ui (GeditCollaborationWindowHelper *helper)
 	                                GTK_POLICY_AUTOMATIC);
 
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
-	                                     GTK_SHADOW_ETCHED_IN);
+	                                     GTK_SHADOW_NONE);
 
 	/* Initialize libinfinity stuff */
 	init_infinity (helper);
